@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2004-2017 CS-SI. All Rights Reserved.
+* Copyright (C) 2004-2019 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude library.
@@ -48,7 +48,7 @@
 # define fchown(x, y, z) (0)
 #endif
 
-extern int server_confirm;
+extern prelude_bool_t server_confirm;
 extern int generated_key_size;
 extern int authority_certificate_lifetime;
 extern int generated_certificate_lifetime;
@@ -409,7 +409,7 @@ static gnutls_x509_crt_t generate_signed_certificate(prelude_client_profile_t *c
                 goto err;
         }
 
-        ret = gnutls_x509_crt_sign(crt, ca_crt, ca_key);
+        ret = gnutls_x509_crt_sign2(crt, ca_crt, ca_key, GNUTLS_DIG_SHA256, 0);
         if ( ret < 0 ) {
                 fprintf(stderr, "error signing certificate: %s.\n", gnutls_strerror(ret));
                 goto err;
@@ -445,7 +445,7 @@ static gnutls_x509_crt_t generate_ca_certificate(prelude_client_profile_t *cp, g
         gnutls_x509_crt_set_ca_status(crt, 1);
         gnutls_x509_crt_set_key_usage(crt, usage);
 
-        ret = gnutls_x509_crt_sign(crt, crt, key);
+        ret = gnutls_x509_crt_sign2(crt, crt, key, GNUTLS_DIG_SHA256, 0);
         if ( ret < 0 ) {
                 fprintf(stderr, "error self-signing certificate: %s.\n", gnutls_strerror(ret));
                 gnutls_x509_crt_deinit(crt);
