@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2002-2017 CS-SI. All Rights Reserved.
+* Copyright (C) 2002-2019 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 * Author: Krzysztof Zaraska
 *
@@ -155,6 +155,20 @@ idmef_value_type_id_t idmef_class_get_child_value_type(idmef_class_id_t class, i
 
 
 
+const char **idmef_class_get_child_attributes(idmef_class_id_t class, idmef_class_child_id_t child)
+{
+        int ret;
+
+        ret = is_child_valid(class, child);
+        if ( ret < 0 )
+                return ret;
+
+        return object_data[class].children_list[child].attributes;
+}
+
+
+
+
 size_t idmef_class_get_child_count(idmef_class_id_t class)
 {
         int ret;
