@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.7.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
 #ifndef YY_YY_IDMEF_CRITERIA_STRING_YAC_H_INCLUDED
 # define YY_YY_IDMEF_CRITERIA_STRING_YAC_H_INCLUDED
-/* Enabling traces.  */
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
 #endif
@@ -40,35 +40,34 @@
 extern int yydebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     TOK_IDMEF_VALUE = 258,
-     TOK_IDMEF_PATH = 259,
-     TOK_RELATION_SUBSTRING = 260,
-     TOK_RELATION_SUBSTRING_NOCASE = 261,
-     TOK_RELATION_NOT_SUBSTRING = 262,
-     TOK_RELATION_NOT_SUBSTRING_NOCASE = 263,
-     TOK_RELATION_REGEXP = 264,
-     TOK_RELATION_REGEXP_NOCASE = 265,
-     TOK_RELATION_NOT_REGEXP = 266,
-     TOK_RELATION_NOT_REGEXP_NOCASE = 267,
-     TOK_RELATION_GREATER = 268,
-     TOK_RELATION_GREATER_OR_EQUAL = 269,
-     TOK_RELATION_LESS = 270,
-     TOK_RELATION_LESS_OR_EQUAL = 271,
-     TOK_RELATION_EQUAL = 272,
-     TOK_RELATION_EQUAL_NOCASE = 273,
-     TOK_RELATION_NOT_EQUAL = 274,
-     TOK_RELATION_NOT_EQUAL_NOCASE = 275,
-     TOK_NOT = 276,
-     TOK_OPERATOR_AND = 277,
-     TOK_OPERATOR_OR = 278,
-     TOK_ERROR = 279
-   };
+  enum yytokentype
+  {
+    TOK_IDMEF_VALUE = 258,
+    TOK_IDMEF_PATH = 259,
+    TOK_RELATION_SUBSTRING = 260,
+    TOK_RELATION_SUBSTRING_NOCASE = 261,
+    TOK_RELATION_NOT_SUBSTRING = 262,
+    TOK_RELATION_NOT_SUBSTRING_NOCASE = 263,
+    TOK_RELATION_REGEXP = 264,
+    TOK_RELATION_REGEXP_NOCASE = 265,
+    TOK_RELATION_NOT_REGEXP = 266,
+    TOK_RELATION_NOT_REGEXP_NOCASE = 267,
+    TOK_RELATION_GREATER = 268,
+    TOK_RELATION_GREATER_OR_EQUAL = 269,
+    TOK_RELATION_LESS = 270,
+    TOK_RELATION_LESS_OR_EQUAL = 271,
+    TOK_RELATION_EQUAL = 272,
+    TOK_RELATION_EQUAL_NOCASE = 273,
+    TOK_RELATION_NOT_EQUAL = 274,
+    TOK_RELATION_NOT_EQUAL_NOCASE = 275,
+    TOK_OPERATOR_NOT = 276,
+    TOK_OPERATOR_AND = 277,
+    TOK_OPERATOR_OR = 278,
+    TOK_ERROR = 279
+  };
 #endif
 /* Tokens.  */
 #define TOK_IDMEF_VALUE 258
@@ -89,48 +88,35 @@ extern int yydebug;
 #define TOK_RELATION_EQUAL_NOCASE 273
 #define TOK_RELATION_NOT_EQUAL 274
 #define TOK_RELATION_NOT_EQUAL_NOCASE 275
-#define TOK_NOT 276
+#define TOK_OPERATOR_NOT 276
 #define TOK_OPERATOR_AND 277
 #define TOK_OPERATOR_OR 278
 #define TOK_ERROR 279
 
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+
+union YYSTYPE
 {
-/* Line 2058 of yacc.c  */
-#line 103 "idmef-criteria-string.yac.y"
+#line 94 "idmef-criteria-string.yac.y" /* yacc.c:1909  */
 
         char *str;
         int operator;
         idmef_path_t *path;
         idmef_criteria_t *criteria;
-        idmef_criterion_operator_t relation;
+        idmef_criteria_operator_t relation;
 
+#line 110 "idmef-criteria-string.yac.h" /* yacc.c:1909  */
+};
 
-/* Line 2058 of yacc.c  */
-#line 114 "idmef-criteria-string.yac.h"
-} YYSTYPE;
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void *YYPARSE_PARAM);
-#else
-int yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
 int yyparse (void);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 #endif /* !YY_YY_IDMEF_CRITERIA_STRING_YAC_H_INCLUDED  */
